@@ -978,7 +978,9 @@ def polarBarRanks(
     # Get Values --------------------------------------------------------------
     vals = {}
     for cat in cats:
-        vals[cat] = list(dfRank[cat].value_counts(normalize=True))[::-1]
+        vals[cat] = list(
+            dfRank[cat].value_counts(sort=False, normalize=True).sort_index()
+        )[::-1]
     # Generate Grid -----------------------------------------------------------
     thetaRange = (0, 90)
     fig = plt.figure(figsize=(10, 10))
